@@ -29,7 +29,7 @@ class SolrException(BaseException):
     pass
 
 
-class Solr():
+class Solr(object):
     _add_batch = []
     _shards = None
 
@@ -41,6 +41,11 @@ class Solr():
             logger.warning("Faulty Solr configuration, SOLR will not be available!")
             return
 
+        self.endpoints = None
+        self.default_endpoint = None
+        self._shards = None
+        self._add_batch = list()
+
         if isinstance(endpoints, basestring):
             self.endpoints = {'default': endpoints}
             self.default_endpoint = "default"
